@@ -31,9 +31,7 @@ Obj = namedtuple("Obj", "path data")
 
 @pytest.fixture
 def fs():
-    fs = V3ioFS()
-    yield fs
-    fs._client.close()
+    yield V3ioFS()
 
 
 @pytest.fixture
