@@ -12,11 +12,11 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-from v3iofs import V3ioFile, V3ioFS
+from v3iofs import V3ioFS
 
 
 def test_fetch_range(fs: V3ioFS, tmp_obj):
-    v3f = V3ioFile(fs, tmp_obj.path)
+    v3f = fs.open(tmp_obj.path)
     start, end = 3, len(tmp_obj.data) - 3
     data = v3f._fetch_range(start, end)
     expected = tmp_obj.data[start:end]
@@ -24,7 +24,7 @@ def test_fetch_range(fs: V3ioFS, tmp_obj):
 
 
 def test_upload_chunk(fs: V3ioFS, tmp_obj):
-    v3f = V3ioFile(fs, tmp_obj.path, "ab")
+    v3f = fs.open(tmp_obj.path, "ab")
     chunk = b"::chunk of data"
     v3f.buffer.write(chunk)
     v3f._upload_chunk()
@@ -37,10 +37,26 @@ def test_upload_chunk(fs: V3ioFS, tmp_obj):
     assert expected == data, "bad data"
 
 
+def test_write_truncate_and_append(fs: V3ioFS, tmp_obj):
+    with fs.open(tmp_obj.path, "wb") as v3f:
+        v3f.write(b"123")
+
+    with fs.open(tmp_obj.path, "rb") as fp:
+        data = fp.read()
+    assert data == b"123"
+
+    with fs.open(tmp_obj.path, "ab") as v3f:
+        v3f.write(b"456")
+
+    with fs.open(tmp_obj.path, "rb") as fp:
+        data = fp.read()
+    assert data == b"123456"
+
+
 def test_initiate_upload(fs: V3ioFS, tmp_obj):
     fs.touch(tmp_obj.path)
     assert fs.exists(tmp_obj.path)
-    v3f = V3ioFile(fs, tmp_obj.path, "wb")
+    v3f = fs.open(tmp_obj.path, "wb")
     v3f._initiate_upload()
     assert not fs.exists(tmp_obj.path)
     # should not fail even if the file does not exist
