@@ -96,16 +96,20 @@ class V3ioFS(AbstractFileSystem):
     cache_capacity: int | str | None
         limits the size of the cache. If cache_validity_seconds is not set, this parameter has no effect.
         Default is 128.
+    debug: bool
+        Turn on transport debug logs. Default is False.
     **kw:
         Passed to fsspec.AbstractFileSystem
     """
 
     protocol = "v3io"
 
-    def __init__(self, v3io_api=None, v3io_access_key=None, cache_validity_seconds=None, cache_capacity=None, **kw):
+    def __init__(
+        self, v3io_api=None, v3io_access_key=None, cache_validity_seconds=None, cache_capacity=None, debug=False, **kw
+    ):
         # TODO: Support storage options for creds (in kw)
         super().__init__(**kw)
-        self._client = _new_client(v3io_api, v3io_access_key)
+        self._client = _new_client(v3io_api, v3io_access_key, debug)
         self._cache = None
         if cache_validity_seconds is None:
             cache_validity_seconds = 2
@@ -119,19 +123,21 @@ class V3ioFS(AbstractFileSystem):
     def ls(self, path, detail=True, marker=None, **kwargs):
         """Lists files & directories under path"""
 
-        full_path = path
         path = strip_schema(path)
         container, path = split_container(path)
         if not container:
             return self._list_containers(detail)
         ext_out = []
 
+        limit = kwargs.get("limit", None)
+
         while True:
             resp = self._client.get_container_contents(
                 container=container,
                 path=path,
                 get_all_attributes=True,
                 raise_for_status=v3io.dataplane.RaiseForStatus.never,
+                limit=limit,
                 marker=marker,
             )
 
@@ -146,7 +152,7 @@ class V3ioFS(AbstractFileSystem):
                 if not _has_data(resp):
                     return [self._ls_file(container, path, detail)]
                 if not out:
-                    raise FileNotFoundError(f"{full_path!r} not found")
+                    return []
 
             ext_out.extend(out)
             if hasattr(resp.output, "next_marker") and resp.output.next_marker:
@@ -193,6 +199,11 @@ class V3ioFS(AbstractFileSystem):
     def copy(self, path1, path2, **kwargs):
         ...  # FIXME
 
+    def rmdir(self, path):
+        if path and not path.endswith("/"):
+            path += "/"
+        self._rm(path)
+
     def _rm(self, path):
         container, path_without_container = split_container(path)
         if not container:
@@ -331,6 +342,8 @@ class V3ioFS(AbstractFileSystem):
         cache_options=None,
         **kw,
     ):
+        if mode != "rb":
+            self._cache.delete_if_exists(path)
         return V3ioFile(
             fs=self,
             path=path,
@@ -443,11 +456,17 @@ def _has_data(resp):
     return hasattr(out, "common_prefixes") or hasattr(out, "contents")
 
 
-def _new_client(v3io_api=None, v3io_access_key=None) -> Client:
+def _new_client(v3io_api=None, v3io_access_key=None, debug=False) -> Client:
     v3io_api = v3io_api or environ.get("V3IO_API")
     v3io_access_key = v3io_access_key or environ.get("V3IO_ACCESS_KEY")
 
+    client_kwargs = {}
+    if debug:
+        client_kwargs["logger_verbosity"] = "DEBUG"
+        client_kwargs["transport_verbosity"] = "DEBUG"
+
     return Client(
         endpoint=v3io_api,
         access_key=v3io_access_key,
+        **client_kwargs,
     )
